@@ -1,5 +1,6 @@
 from nislmigrate.facades.file_system_facade import FileSystemFacade
 from nislmigrate.facades.mongo_facade import MongoFacade
+from nislmigrate.facades.process_facade import ProcessFacade
 from nislmigrate.facades.system_link_service_manager_facade import SystemLinkServiceManagerFacade
 
 
@@ -13,7 +14,8 @@ class FacadeFactory:
         """
         Creates a new instance of MigratorFactory.
         """
-        self.mongo_facade: MongoFacade = MongoFacade()
+        self.process_facade: ProcessFacade = ProcessFacade()
+        self.mongo_facade: MongoFacade = MongoFacade(self.process_facade)
         self.file_system_facade: FileSystemFacade = FileSystemFacade()
         self.system_link_service_manager_facade: SystemLinkServiceManagerFacade = SystemLinkServiceManagerFacade()
 
@@ -34,3 +36,6 @@ class FacadeFactory:
         Gets a SystemLinkServiceManagerFacade instance.
         """
         return self.system_link_service_manager_facade
+
+    def get_process_facade(self) -> ProcessFacade:
+        return self.process_facade
